
#if defined(BUILD_DLL) && defined(WIN32)
	#define DLL_ACTION  __declspec(dllexport)
	#define STDCALL     __stdcall
#elif defined(WIN32)
	#define DLL_ACTION  __declspec(dllimport)
	#define STDCALL     __stdcall	
#else
	#define DLL_ACTION
	#define STDCALL 
#endif

//
// definizione e dimensioni dei buffer:
// smallest_string = lunghezza 32 bytes
// medium_string = lunghezza 128 bytes

//
// struttura da utilizzare per l'invio in threads:
//  
// struct smsuser_t {
//   char 	 *phone  // dimensione massima 32 bytes;
//   char 	 *message // dimensione massima 361;
//   TSender   *forClass; // riferimento che pu essere ignorato
// };


// funzioni esportate:
extern "C" {
	/*
		Funzione: vodafone_init_account
		-----------------------------------------------------------------------------
		Descrizione: permette di autenticarsi presso il sito vodafone per usufruire
					 dei servizi riservati.
		Parametri:	 tre parametri di tipo stringa (puntatori a char)
		             getSimInfo: se true, reperisce le info sulle sim (pi lento)
		                         false, usa la sim di default.
					 username: nome login da utilizzare per l'accesso
					 password: parola segreta da utilizzare per l'accesso
		Restituisce: valore boolean
					 true: se il riconoscimento dell'utente avviene con successo
					 false: in caso contrario
	    ATTENZIONE:  terminare sempre il login con la vodafone_destroy_account().
	                 Non chiudendo l'account, non si garantisce l'aggiornamento 
                     delle SIM per il successivo login con vodafone_init_account().
        --> NOTA:	 la funzione vodafone_init_account(), reperisce sempre le info
                     sulle sim per l'account corrente.
		------------------------------------------------------------------------------
	*/
	DLL_ACTION bool STDCALL vodafone_init_account(const char *username, const char *password);
	DLL_ACTION bool STDCALL vodafone_init_account_with_sim(bool getSimInfo, const char *username, const char *password);	


	/*
		Funzione: vodafone_destroy_account
		-----------------------------------------------------------------------------
		Descrizione: permette di effettuare il logout presso il sito vodafone.
		Parametri:	 nessun parametro
		Restituisce: valore boolean
					 true: se il logout per l'utente avviene con successo
					 false: in caso contrario
    	NOTA:		 Il parametro di ritorno non garantisce che il logout avvenga
        			 con certezza. 
	    ATTENZIONE:  la mancanza di utilizzo di questa funzione, previa precedente
	                 autenticazione, non garantisce l'aggiornamento delle SIM per
	                 il successivo login con vodafone_init_account().
		------------------------------------------------------------------------------
	*/
	DLL_ACTION bool STDCALL vodafone_destroy_account(void);


	/*
		Funzione: vodafone_send_sync_sms
		-----------------------------------------------------------------------------
		Descrizione: permette di usufruire del servizio di invio SMS verso cellulari
					 omnitel, previa autenticazione. Vedere vodafone_init_account.
					 La funzione permette di inviare messaggi (> 120 car) senza
					 usufruire dello split automatico del sito vodafone; questo
					 per evitare l'invio scoordinato degli sms. 
		Parametri:	due parametri di tipo stringa (puntatori a char)
					 phone: numero di telefono destinatario
					 message: messaggio da inviare al numero di destinazione.
				Lunghezza massima 360 caratteri (no demo version).
		Restituisce: valore boolean
					 true: se la consegna del messaggio al provider  avvenuta.
					 false: in caso contrario; false non indica che nessun invio
                      avvenuto.
		Note:		 La consegna del messaggio non garantisce che questo venga
					 inviato subito al destinatario.					 
	    ATTENZIONE:  usare questa funzione SOLO se si  sicuri che il messaggio
	                 potr essere splittato altrimenti pu essere lenta e sprecare
	                 pi invii.
		------------------------------------------------------------------------------
	*/
	DLL_ACTION bool STDCALL vodafone_send_sync_sms(char *phone, char *message);


	/*
		Funzione: vodafone_init_multiple_account
		-----------------------------------------------------------------------------
		Descrizione: permette di autenticarsi presso il sito vodafone per usufruire
					 dei servizi riservati. 
                     VALIDA SOLO PER LA FUNZIONE vodafone_send_sync_sms().
		Parametri:	 due parametri di tipo stringa (puntatori a char)
					 username: nome login da utilizzare per l'accesso
					 password: parola segreta da utilizzare per l'accesso
		Restituisce: nulla
		Nota:        richiamare SOLO se si utilizza la funzione di invio
		             multiplo.
		------------------------------------------------------------------------------
	*/        
    DLL_ACTION void STDCALL vodafone_init_multiple_account(const char *username, const char *password);
      
        
	/*
        Funzione: vodafone_send_multiple_sms
        -----------------------------------------------------------------------------
        Descrizione: permette di usufruire del servizio di invio SMS verso cellulari
        omnitel in modalit multi-threading.
        Parametri: un parametri di tipo generico (puntatori a void)
        		array: puntatore a struttura smsuser_t (descritta ad inizio pagina)
        Restituisce: valore boolean
        		true: se la consegna dei messaggi al provider  avvenuta.
        		false: in caso contrario
        Note:		 La consegna del messaggio non garantisce che questo venga
        inviato subito al destinatario.
        ATTENZIONE: prima di chiamare questa funzione, si deve usare la 
        	      vodafone_init_multiple_account. 
        	      Non  necessaria una precedente chiamata a vodafone_init_account.
        ------------------------------------------------------------------------------
        */        
        DLL_ACTION bool STDCALL vodafone_send_multiple_sms(void *array, unsigned short num_thread);
        DLL_ACTION bool STDCALL vodafone_send_multiple_sms_with_sim(void *array, unsigned short num_thread, 
                char *sim_to_use);        
	/*
		Funzione: vodafone_send_sms
		-----------------------------------------------------------------------------
		Descrizione: permette di usufruire del servizio di invio SMS verso cellulari
					 omnitel, previa autenticazione. Vedere vodafone_init_account.
		Parametri:	 due parametri di tipo stringa (puntatori a char)
					 phone: numero di telefono destinatario
					 message: messaggio da inviare al numero di destinazione.
							  Lunghezza massima 360 caratteri (no demo version).
		Restituisce: valore boolean
					 true: se la consegna del messaggio al provider  avvenuta.
					 false: in caso contrario
		Note:		 La consegna del messaggio non garantisce che questo venga
					 inviato subito al destinatario.
		------------------------------------------------------------------------------
	*/
	DLL_ACTION bool STDCALL vodafone_send_sms(char *phone, char *message);


	/*
		Funzione: vodafone_get_max_sms_length
		-----------------------------------------------------------------------------
		Descrizione: restituisce il numero massimo di caratteri che  possibile
        			 utilizzare all'interno di un sms.
		Parametri:	 nessuno
		Restituisce: valore intero
        			 numero di caratteri che  possibile utilizzare.
		------------------------------------------------------------------------------
	*/
    	DLL_ACTION int STDCALL vodafone_get_max_sms_length(void);


	/*
		Funzione: vodafone_get_tot_sms_sent
		-----------------------------------------------------------------------------
		Descrizione: restituisce il numero totale di sms inviati con successo.
		             Il valore  valido per la sim correntemente selezionata
		             (vedere la funzione vodafone_get_current_used_sim)
		Parametri:	 nessuno
		Restituisce: valore intero
				     numero di messaggi che sono stati inviati con successo durante
					 la sessione aperta.
		Nota:        Per durata della sessione si intende dalla creazione di una istanza
					 della dll fino alla sua distruzione.
		ATTENZIONE:  il valore restituito  volatile; per cui, prima della
					 distruzione dell'oggetto, assicurarsi di memorizzarlo
					 se si intende usarlo successivamente.
		------------------------------------------------------------------------------
	*/
	DLL_ACTION int STDCALL vodafone_get_tot_sms_sent(void);


	/*
		Funzione: vodafone_get_tot_sms_error
		-----------------------------------------------------------------------------
		Descrizione: restituisce il numero totale di sms per cui  avvenuto un
					 tentativo di invio non andato a buon fine.
		             Il valore  valido per la sim correntemente selezionata
		             (vedere la funzione vodafone_get_current_used_sim)					 
		Parametri:	 nessuno
		Restituisce: valore intero
				     numero di messaggi che non sono stati inviati con successo durante
					 la sessione aperta.
		Nota:        Per durata della sessione si intende dalla creazione di una istanza
					 della dll fino alla sua distruzione. La funzione tiene traccia di 
					 tutti gli invii non andati a buon fine, sia per un dato sms che per
					 gli altri. Valore cumulativo.
		ATTENZIONE:  il valore restituito  volatile; per cui, prima della
					 distruzione dell'oggetto, assicurarsi di memorizzarlo
					 se si intende usarlo successivamente.
		------------------------------------------------------------------------------
	*/
	DLL_ACTION int STDCALL vodafone_get_tot_sms_error(void);


	
	/*
		Funzione: vodafone_get_login
		-----------------------------------------------------------------------------
		Descrizione: permette di usufruire del servizio di identificazione del
					 cliente appena autenticatosi. Vedere vodafone_init_account.
		Parametri:	 un parametro di tipo stringa (puntatori a char)
					 ret_smallest_login: buffer di dimensione 32 bytes in cui
					 verr riposto il nome utente di benvenuto.
		Restituisce: nuemero di caratteri effettivamente copiati
		Note:		  cura del programmatore allocare la memoria necessaria per
					 contenere i dati restituiti. In caso di chiamata senza precedente
					 autenticazione, il buffer di memoria sar posto a zero.
		------------------------------------------------------------------------------
	*/
	DLL_ACTION unsigned short STDCALL vodafone_get_login(char *ret_smallest_login);


	/*
		Funzione: vodafone_get_total_sims
		-----------------------------------------------------------------------------
		Descrizione: ottiene il numero complessivo di sim registrate nell'account.
		Parametri:   nessuno
		Restituisce: nuemero di sim per l'account
		------------------------------------------------------------------------------
	*/
    DLL_ACTION unsigned short STDCALL vodafone_get_total_sims(void);
    

	/*
		Funzione: vodafone_is_used_sim
		-----------------------------------------------------------------------------
		Descrizione: controlla se la sim identificata da indexSim  quella 
                     correntemente utilizzata.
		Parametri:   indexSim: indice della sim per cui si vuole avere conferma
		Restituisce: true se la sim  quella utilizzata al momento, false altrimenti.
		------------------------------------------------------------------------------
	*/    
    DLL_ACTION bool STDCALL vodafone_is_used_sim(unsigned short indexSim);
    
    
	/*
		Funzione: vodafone_get_current_used_sim
		-----------------------------------------------------------------------------
		Descrizione: restituisce il numero di cellulare attualmente utilizzato
                     per inviare gli sms.
		Parametri:	 un parametro di tipo stringa (puntatori a char)
					 ret_smallest_phone: buffer di dimensione 32 bytes in cui
					 verr riposto il numero di telefono.
		Restituisce: nuemero di caratteri effettivamente copiati
		Note:		  cura del programmatore allocare la memoria necessaria per
					 contenere i dati restituiti. In caso di chiamata senza precedente
					 autenticazione, il buffer di memoria sar posto a zero.
		------------------------------------------------------------------------------
	*/
    DLL_ACTION unsigned short STDCALL vodafone_get_current_used_sim(char *ret_smallest_phone);
    
	
    /*
		Funzione: vodafone_set_other_sim - 2 versioni
		-----------------------------------------------------------------------------
		Descrizione: permette di settare la sim da utilizzare per l'invio degli sms.
		             Per coloro che hanno pi sim registrate in un unico account
		             sul sito vodafone.
		Parametri:	 un parametro di tipo stringa (puntatori a char)
					 smallest_phone: buffer di dimensione 32 bytes in cui
					  contenuto il numero che si intende usare.
					 O indice della sim che si intende impostare come attiva.
		Restituisce: true se il settaggio  avvenuto, false altrimenti.
		------------------------------------------------------------------------------
	*/    
    DLL_ACTION bool STDCALL vodafone_set_other_sim(char *smallest_phone);
    DLL_ACTION bool STDCALL vodafone_set_other_sim_by_index(unsigned short indexSim);    


    /*
		Funzione: vodafone_get_sim
		-----------------------------------------------------------------------------
		Descrizione: reperisce una sim nell'insieme relativoe all'account.
		Parametri:	 un parametro di tipo stringa (puntatori a char)
					 ret_smallest_phone: buffer di dimensione 32 bytes in cui
					 verr inserito il numero.
					 indexSim: indice che identifica la sim che si vuole ottenere.
		Restituisce: numero di caratteri del numero reperito. Altrimenti zero.
		------------------------------------------------------------------------------
	*/    
    DLL_ACTION unsigned short STDCALL vodafone_get_sim(char *ret_smallest_phone, unsigned short indexSim);
    
    
	/*
		Funzione: vodafone_get_credit
		-----------------------------------------------------------------------------
		Descrizione: restituisce informazioni sulla libreria e sul creatore della
					 stessa.
		Parametri:	 un parametro di tipo stringa (puntatori a char)
					 ret_medium_version: buffer di dimensione 128 bytes in cui
					 verr riposto il credito.
		Restituisce: nuemero di caratteri effettivamente copiati
		Note:		  cura del programmatore allocare la memoria necessaria per 
					 contenere i dati restituiti. In caso di errore, il buffer di 
					 memoria sar posto a zero.
		------------------------------------------------------------------------------
	*/
	DLL_ACTION unsigned short STDCALL vodafone_get_credit(char *ret_medium_version);
}
