

#if defined(BUILD_DLL) && defined(WIN32)
	#define DLL_ACTION 	__declspec(dllexport)
	#define STDCALL     __stdcall
#elif defined(WIN32)
	#define DLL_ACTION  __declspec(dllimport)
	#define STDCALL     __stdcall	
#else
	#define DLL_ACTION
	#define STDCALL 
#endif


//
// definizione e dimensioni dei buffer:
// smallest_string = lunghezza 32 bytes
// small_string = lunghezza 64 bytes               
// medium_string = lunghezza 128 bytes
// large_string = lunghezza 256 bytes
// largest_string = lunghezza 512 bytes



extern "C" {
	/*
		Funzione: virgilio_init_account
		-----------------------------------------------------------------------------
		Descrizione: permette di autenticarsi presso il sito virgilio per usufruire
					 dei servizi riservati.
		Parametri:	 tre parametri di tipo stringa (puntatori a char)
					 username: nome login da utilizzare per l'accesso senza dominio.
					 password: parola segreta da utilizzare per l'accesso
					 dominio: identifica il dominio su cui operare:
                              "virgilio.it"  per servizi Virgilio (testato)
                              "tin.it"       per servizi Tin (non testato)
                              "alice.it"     per servizi Alice (non considerato)
		Restituisce: valore boolean
					 true: se il riconoscimento dell'utente avviene con successo
					 false: in caso contrario
		------------------------------------------------------------------------------
	*/
	DLL_ACTION bool STDCALL virgilio_init_account(const char *username, const char *password, const char *dominio);



	/*
		Funzione: virgilio_destroy_account
		-----------------------------------------------------------------------------
		Descrizione: permette di effettuare il logout presso il sito virgilio.
		Parametri:	 nessun parametro
		Restituisce: valore boolean
					 true: se il logout per l'utente avviene con successo
					 false: in caso contrario
    	NOTA:		 Il parametro di ritorno non garantisce che il logout avvenga
        			 con certezza. 
		------------------------------------------------------------------------------
	*/
    DLL_ACTION bool STDCALL virgilio_destroy_account(void);
    
    
    
	/*
		Funzione: virgilio_control_new_mail
		-----------------------------------------------------------------------------
		Descrizione: previa autenticazione, restituisce il numero di nuovi 
		             messaggi e-mail presenti per l'account.
		Parametri:	 nessuno
		Restituisce: valore numerico
					 = 0: se non ci sono nuove mail
					 > 0: in caso sono presenti nuove mail
					 -1 : in caso di mancata autenticazione o errore
		------------------------------------------------------------------------------
	*/
    DLL_ACTION long STDCALL virgilio_control_new_mail(void);
    
    
	/*
		Funzione: virgilio_get_all_prefix_number
		-----------------------------------------------------------------------------
		Descrizione: previa autenticazione, reperisce tutti i prefissi, nazionali
                     ed internazionali, a cui  possibile inviare sms.
		Parametri:	 variabile di tipo char
                     delimiter: indica il carattere che separer ogni elemento
                                dell'array, secondo il seguente formato 
                                (es con delimiter= '$'):
                                prefisso|titolo$prefisso|titolo$...
                                La pipe (|) separa di default il prefisso ed il titolo.
                     variabile di tipo puntatore:
                               conterr i dati dei prefissi
		Restituisce: numero di caratteri memorizzati nel buffer.
		             restituisce zero se non  stato scritto nulla.
		NOTA:         cura del programmatore allocare una quantit abbastanza
                     grande da contenere i dati.
		------------------------------------------------------------------------------
	*/
    DLL_ACTION unsigned short STDCALL virgilio_get_all_prefix_number(char *retBuffer, char delimiter);
    

	/*
		Funzione: virgilio_send_sms
		-----------------------------------------------------------------------------
		Descrizione: previa autenticazione, permette di inviare sms.
		Parametri:	 due puntatori a carattere
		             phone: rappresenta il numero telefonico a cui inviare l'sms;
		                    deve contenere anche il prefisso internazionale (es: +39)
                     message: messaggio che deve essere inviato.
		Restituisce: valore booleano
					 true: invio eseguito correttamente
					 false: altrimenti
		------------------------------------------------------------------------------
	*/    
    DLL_ACTION bool STDCALL virgilio_send_sms(char *phone, char *message);



	/*
		Funzione: virgilio_get_max_char_sms
		-----------------------------------------------------------------------------
		Descrizione: previa autenticazione, permette di reperire il numero
		             massimo di caratteri che costituiscono un sms.
        Parametri:   nessuno
		Restituisce: valore numerico
					 > 0: caratteri disponibili per un sms
					 = 0: errore (autorizzazione non avvenuta o problemi di conn.)
		------------------------------------------------------------------------------
	*/    
    DLL_ACTION unsigned short STDCALL virgilio_get_max_char_sms(void);
    
    
    
	/*
		Funzione: virgilio_get_info_sms
		-----------------------------------------------------------------------------
		Descrizione: previa autenticazione, permette di ottenere informazioni
		             sullo stato degli sms.
		Parametri:   due puntatori a short
		             max_sms: verr memorizzato il numero di sms consentito 
		                      giornalmente.
                     cur_sent: verr memorizzato il numero di sms inviati.
		Restituisce: valore booleano
					 true: informazioni reperite correttamente
					 false: altrimenti ed imposta le variabili al valore 0.
		------------------------------------------------------------------------------
	*/    
    DLL_ACTION bool STDCALL virgilio_get_info_sms(unsigned short *max_sms, unsigned short *cur_sent);
    
};
